{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Downsample and HaplotypeCaller",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "record",
                            "name": "#main/crams_to_downsample/crams",
                            "fields": [
                                {
                                    "type": "float",
                                    "doc": "contamination score to pass to HaplotypeCaller",
                                    "name": "#main/crams_to_downsample/crams/contamination"
                                },
                                {
                                    "type": "File",
                                    "name": "#main/crams_to_downsample/crams/cram"
                                },
                                {
                                    "type": "float",
                                    "doc": "the downsample ratio to use when reprocessing this CRAM",
                                    "name": "#main/crams_to_downsample/crams/downsample_ratio"
                                }
                            ]
                        }
                    },
                    "id": "#main/crams_to_downsample"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/downsample_seed"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/downsample_strategy/HighAccuracy",
                                "#main/downsample_strategy/ConstantMemory",
                                "#main/downsample_strategy/Chained"
                            ]
                        }
                    ],
                    "id": "#main/downsample_strategy"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#main/emit_reference_confidence/NONE",
                            "#main/emit_reference_confidence/BP_RESOLUTION",
                            "#main/emit_reference_confidence/GVCF"
                        ]
                    },
                    "id": "#main/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "doc": "arrays of intervals to use in each individual run of the haplotypecaller",
                    "id": "#main/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/max_alternate_alleles"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/ploidy"
                },
                {
                    "type": "int",
                    "id": "#main/qc_minimum_base_quality"
                },
                {
                    "type": "int",
                    "id": "#main/qc_minimum_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/read_filter"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "doc": "The reference that was used for the already-completed alignments",
                    "id": "#main/reference"
                }
            ],
            "steps": [
                {
                    "run": "#collect_wgs_metrics.cwl",
                    "scatter": [
                        "#main/collect_wgs_metrics/bam",
                        "#main/collect_wgs_metrics/sample_name"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/downsample/downsampled_sam",
                            "id": "#main/collect_wgs_metrics/bam"
                        },
                        {
                            "source": "#main/qc_minimum_base_quality",
                            "id": "#main/collect_wgs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#main/qc_minimum_mapping_quality",
                            "id": "#main/collect_wgs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_wgs_metrics/reference"
                        },
                        {
                            "source": "#main/downsample/downsampled_sam",
                            "valueFrom": "$(self.nameroot)",
                            "id": "#main/collect_wgs_metrics/sample_name"
                        }
                    ],
                    "out": [
                        "#main/collect_wgs_metrics/wgs_metrics"
                    ],
                    "id": "#main/collect_wgs_metrics"
                },
                {
                    "run": "#downsample.cwl",
                    "scatter": [
                        "#main/downsample/sam",
                        "#main/downsample/probability"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/crams_to_downsample",
                            "valueFrom": "$(self.downsample_ratio)",
                            "id": "#main/downsample/probability"
                        },
                        {
                            "source": "#main/downsample_seed",
                            "id": "#main/downsample/random_seed"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/downsample/reference"
                        },
                        {
                            "source": "#main/crams_to_downsample",
                            "valueFrom": "$(self.cram)",
                            "id": "#main/downsample/sam"
                        },
                        {
                            "source": "#main/downsample_strategy",
                            "id": "#main/downsample/strategy"
                        }
                    ],
                    "out": [
                        "#main/downsample/downsampled_sam"
                    ],
                    "id": "#main/downsample"
                },
                {
                    "run": "#gatk_haplotypecaller_iterator.cwl",
                    "scatter": [
                        "#main/haplotype_caller/bam",
                        "#main/haplotype_caller/contamination_fraction",
                        "#main/haplotype_caller/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/downsample/downsampled_sam",
                            "id": "#main/haplotype_caller/bam"
                        },
                        {
                            "source": "#main/crams_to_downsample",
                            "valueFrom": "$(self.contamination)",
                            "id": "#main/haplotype_caller/contamination_fraction"
                        },
                        {
                            "source": "#main/emit_reference_confidence",
                            "id": "#main/haplotype_caller/emit_reference_confidence"
                        },
                        {
                            "default": [],
                            "id": "#main/haplotype_caller/gvcf_gq_bands"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/haplotype_caller/intervals"
                        },
                        {
                            "source": "#main/max_alternate_alleles",
                            "id": "#main/haplotype_caller/max_alternate_alleles"
                        },
                        {
                            "source": "#main/downsample/downsampled_sam",
                            "valueFrom": "$(self.nameroot + \".downsampled.\")",
                            "id": "#main/haplotype_caller/output_prefix"
                        },
                        {
                            "source": "#main/ploidy",
                            "id": "#main/haplotype_caller/ploidy"
                        },
                        {
                            "source": "#main/read_filter",
                            "id": "#main/haplotype_caller/read_filter"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#main/haplotype_caller/gvcf"
                    ],
                    "id": "#main/haplotype_caller"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "outputSource": "#main/haplotype_caller/gvcf",
                    "id": "#main/gvcfs"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_wgs_metrics/wgs_metrics",
                    "id": "#main/wgs_metrics"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "scatter GATK HaplotypeCaller over intervals",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/contamination_fraction"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/dbsnp_vcf"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence/NONE",
                            "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence/BP_RESOLUTION",
                            "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence/GVCF"
                        ]
                    },
                    "id": "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#gatk_haplotypecaller_iterator.cwl/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#gatk_haplotypecaller_iterator.cwl/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/max_alternate_alleles"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "an optional string to prepend to the output filename",
                    "id": "#gatk_haplotypecaller_iterator.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/ploidy"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/read_filter"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/gvcf"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/intervals"
                    ],
                    "run": "#gatk_haplotype_caller.cwl",
                    "in": [
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/bam",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/bam"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/contamination_fraction",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/contamination_fraction"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/dbsnp_vcf",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/dbsnp_vcf"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/emit_reference_confidence"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/gvcf_gq_bands",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf_gq_bands"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/intervals",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/intervals"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/max_alternate_alleles",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/max_alternate_alleles"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/output_prefix",
                            "valueFrom": "${ var prefix = self !== null ? self : \"\"; if (inputs.intervals.length == 1 && inputs.intervals[0].match(/^[0-9A-Za-z]+$/)) { return prefix + inputs.intervals[0] + \".g.vcf.gz\"; } else { return prefix + \"output.g.vcf.gz\"; } }",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/output_file_name"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/ploidy",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/ploidy"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/read_filter",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/read_filter"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/reference",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller"
                }
            ],
            "id": "#gatk_haplotypecaller_iterator.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect WGS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectWgsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.sample_name).WgsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/picard:2.23.6"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_wgs_metrics.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "INTERVALS="
                    },
                    "id": "#collect_wgs_metrics.cwl/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Minimum base quality for a base to contribute coverage. (N bases are considered to have negative infinite quality and will be excluded regardless of this value.)",
                    "inputBinding": {
                        "prefix": "MINIMUM_BASE_QUALITY="
                    },
                    "id": "#collect_wgs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Minimum mapping quality for a read to contribute coverage.",
                    "inputBinding": {
                        "prefix": "MINIMUM_MAPPING_QUALITY="
                    },
                    "id": "#collect_wgs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_wgs_metrics.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "final",
                    "id": "#collect_wgs_metrics.cwl/sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_name).WgsMetrics.txt"
                    },
                    "id": "#collect_wgs_metrics.cwl/wgs_metrics"
                }
            ],
            "id": "#collect_wgs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "downsample unaligned BAM",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx16g",
                "DownsampleSam"
            ],
            "arguments": [
                "--OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.sam.nameroot).bam"
                },
                "--CREATE_INDEX",
                "--CREATE_MD5_FILE"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.4.1"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "--PROBABILITY=",
                        "separate": false
                    },
                    "id": "#downsample.cwl/probability"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--RANDOM_SEED=",
                        "separate": false
                    },
                    "id": "#downsample.cwl/random_seed"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--REFERENCE_SEQUENCE=",
                        "separate": false
                    },
                    "id": "#downsample.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--INPUT=",
                        "separate": false
                    },
                    "id": "#downsample.cwl/sam"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#downsample.cwl/strategy/HighAccuracy",
                                "#downsample.cwl/strategy/ConstantMemory",
                                "#downsample.cwl/strategy/Chained"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--STRATEGY=",
                        "separate": false
                    },
                    "id": "#downsample.cwl/strategy"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".md5",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.sam.nameroot).bam"
                    },
                    "id": "#downsample.cwl/downsampled_sam"
                }
            ],
            "id": "#downsample.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GATK HaplotypeCaller",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx16g",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-contamination",
                        "position": 7
                    },
                    "id": "#gatk_haplotype_caller.cwl/contamination_fraction"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/dbsnp_vcf"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#gatk_haplotype_caller.cwl/emit_reference_confidence/NONE",
                            "#gatk_haplotype_caller.cwl/emit_reference_confidence/BP_RESOLUTION",
                            "#gatk_haplotype_caller.cwl/emit_reference_confidence/GVCF"
                        ]
                    },
                    "inputBinding": {
                        "prefix": "-ERC",
                        "position": 3
                    },
                    "id": "#gatk_haplotype_caller.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GQB"
                        }
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#gatk_haplotype_caller.cwl/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#gatk_haplotype_caller.cwl/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "maximum number of alternate alleles to genotype",
                    "inputBinding": {
                        "prefix": "--max_alternate_alleles",
                        "position": 8
                    },
                    "id": "#gatk_haplotype_caller.cwl/max_alternate_alleles"
                },
                {
                    "type": "string",
                    "default": "output.g.vcf.gz",
                    "inputBinding": {
                        "prefix": "-O",
                        "position": 11
                    },
                    "id": "#gatk_haplotype_caller.cwl/output_file_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "number of chromosomes per sample",
                    "inputBinding": {
                        "prefix": "-ploidy",
                        "position": 9
                    },
                    "id": "#gatk_haplotype_caller.cwl/ploidy"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "filters to apply to reads before analysis",
                    "inputBinding": {
                        "prefix": "--read_filter",
                        "position": 10
                    },
                    "id": "#gatk_haplotype_caller.cwl/read_filter"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#gatk_haplotype_caller.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file_name)"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/gvcf"
                }
            ],
            "id": "#gatk_haplotype_caller.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
